-------------------------------------------------------------------------------
-- Title      : EB675001DIP User CPLD template
-------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity template is
    Port ( --# CPU interface
	 		  nrst_i : in std_logic;								--# reset
           cko_i : in std_logic;									--# clock out from Oki
           nxcs_i : in std_logic_vector(3 downto 2);		--# I/O bank chip select
           nxoe_i : in std_logic;								--# output enable / read enable
           nxwe_i : in std_logic;								--# write enable
           nubs_i : in std_logic;                        --# upper byte select
           nlbs_i : in std_logic;                        --# lower byte select
           xwait_o : out std_logic;								--# external I/O bank wait signal 
           xd : inout std_logic_vector(15 downto 0);		--# data bus
           xa_i : in std_logic_vector(23 downto 21);		--# upper address bus to dicern I/O access or MEM access
           xa0_i : in std_logic;									--# Lower address bus to dicern I/O access or MEM access
			  --# Dedicated pins
			  ncplden_i : in std_logic;							--# cpld enable from ctrl cpld
			  nbufen_io : inout std_logic;						--# buffer enable (address bus)
			  nwait_i : in std_logic;								--# wait pin from davicom (network)

           --# GPIO
			  a : inout std_logic_vector(7 downto 3);
			  b : inout std_logic_vector(7 downto 3);
           c : inout std_logic_vector(14 downto 3);
           d : inout std_logic_vector(16 downto 3);
           d_18 : inout std_logic;
           d_19 : inout std_logic;
           d_20 : inout std_logic;
			  d_29 : inout std_logic
			  );
end template;

architecture Arch of template is


----------------------------------------------------------------------------
-- DO NOT REMOVE
----------------------------------------------------------------------------
signal user_wait_n : std_logic;		-- Internal wait user pin, active low
signal nbufen : std_logic;				-- Internal buffer enable, active low
signal user_bus_out : std_logic_vector(15 downto 0);
signal ncs : std_logic;



begin


----------------------------------------------------------------------------
--				!!!			OPTIONAL LOGIC			!!!
----------------------------------------------------------------------------
--
-- nbufen_io :	Use only if the design has to output the address bus to 
--					the outside world, enable address buffers
--
----------------------------------------------------------------------------
	
	--nbufen_io <= nbufen when nbufen='0' else 'Z';
	--nbufen <= cs_n_i(2) and cs_n_i(3) and ncplden_i;

	-- Drive the data bus to cpu (read command)
	--xd(7 downto 0) <= user_bus_out(7 downto 0) when nxoe_i='0' and ncs='0' and nlbs_i='0' else (others=>'Z')  ;
	--xd(15 downto 8) <= user_bus_out(15 downto 8) when nxoe_i='0' and ncs='0' and nubs_i='0' else (others=>'Z')  ;
 	--ncs <= cs_n_i(2) and cs_n_i(3) and  ncplden_i;

----------------------------------------------------------------------------
--	!!!			CHANGE ONLY IF YOU KNOW WHAT YOU ARE DOING			!!!
----------------------------------------------------------------------------
--
--	user_wait_n : 	If not used must be set to one otherwise wait pin will be
--						active all the time holding the cpu indefinetly
--	nwait_i 		: 	Is the network controller wait signal and has to be routed
--						to the cpu for correct operation
--
----------------------------------------------------------------------------
 	xwait_o <= '1' when nwait_i='0' or user_wait_n='0' else '0';
	user_wait_n <= '1';	


----------------------------------------------------------------------------
--	!!!			USER DESIGN			!!!
----------------------------------------------------------------------------




end Arch;
